@@ -19,9 +19,7 @@
 
 #include "empathy-server-sasl-handler.h"
 
-#include <telepathy-glib/telepathy-glib.h>
-
-#include <extensions/extensions.h>
+#include <telepathy-glib/util.h>
 
 #include <string.h>
 
@@ -126,7 +124,7 @@ empathy_server_sasl_handler_get_password_async_cb (GObject *source,
 
   priv = EMPATHY_SERVER_SASL_HANDLER (user_data)->priv;
 
-  password = empathy_keyring_get_password_finish (TP_ACCOUNT (source),
+  password = empathy_keyring_get_account_password_finish (TP_ACCOUNT (source),
       result, &error);
 
   if (password != NULL)
@@ -157,7 +155,7 @@ empathy_server_sasl_handler_init_async (GAsyncInitable *initable,
   priv->async_init_res = g_simple_async_result_new (G_OBJECT (self),
       callback, user_data, empathy_server_sasl_handler_new_async);
 
-  empathy_keyring_get_password_async (priv->account,
+  empathy_keyring_get_account_password_async (priv->account,
       empathy_server_sasl_handler_get_password_async_cb, self);
 }
 
@@ -376,7 +374,7 @@ empathy_server_sasl_handler_set_password_cb (GObject *source,
 {
   GError *error = NULL;
 
-  if (!empathy_keyring_set_password_finish (TP_ACCOUNT (source), result,
+  if (!empathy_keyring_set_account_password_finish (TP_ACCOUNT (source), result,
           &error))
     {
       DEBUG ("Failed to set password: %s", error->message);
@@ -396,7 +394,6 @@ empathy_server_sasl_handler_provide_password (
 {
   EmpathyServerSASLHandlerPriv *priv;
   GArray *array;
-  gboolean may_save_response, may_save_response_valid;
 
   g_return_if_fail (EMPATHY_IS_SERVER_SASL_HANDLER (handler));
 
@@ -417,50 +414,10 @@ empathy_server_sasl_handler_provide_password (
 
   DEBUG ("%sremembering the password", remember ? "" : "not ");
 
-  /* determine if we are permitted to save the password locally */
-  may_save_response = tp_asv_get_boolean (
-      tp_channel_borrow_immutable_properties (priv->channel),
-      TP_PROP_CHANNEL_INTERFACE_SASL_AUTHENTICATION_MAY_SAVE_RESPONSE,
-      &may_save_response_valid);
-
-  if (!may_save_response_valid)
-    {
-      DEBUG ("MaySaveResponse unknown, assuming TRUE");
-      may_save_response = TRUE;
-    }
-
   if (remember)
     {
-      if (may_save_response)
-        {
-          DEBUG ("Saving password in keyring");
-          empathy_keyring_set_password_async (priv->account, password,
-              empathy_server_sasl_handler_set_password_cb, NULL);
-        }
-      else if (tp_proxy_has_interface_by_id (priv->channel,
-            EMP_IFACE_QUARK_CHANNEL_INTERFACE_CREDENTIALS_STORAGE))
-        {
-          DEBUG ("Channel implements Ch.I.CredentialsStorage");
-        }
-      else
-        {
-          DEBUG ("Asked to remember password, but doing so is not permitted");
-        }
-    }
-
-  if (!may_save_response)
-    {
-      /* delete any password present, it shouldn't be there */
-      empathy_keyring_delete_password_async (priv->account, NULL, NULL);
-    }
-
-  /* Additionally, if we implement Ch.I.CredentialsStorage, inform that
-   * whether we want to remember the password */
-  if (tp_proxy_has_interface_by_id (priv->channel,
-        EMP_IFACE_QUARK_CHANNEL_INTERFACE_CREDENTIALS_STORAGE))
-    {
-      emp_cli_channel_interface_credentials_storage_call_store_credentials (
-          TP_PROXY (priv->channel), -1, remember, NULL, NULL, NULL, NULL);
+      empathy_keyring_set_account_password_async (priv->account, password,
+          empathy_server_sasl_handler_set_password_cb, NULL);
     }
 }
 
@@ -493,18 +450,6 @@ empathy_server_sasl_handler_get_account (EmpathyServerSASLHandler *handler)
   return priv->account;
 }
 
-TpChannel *
-empathy_server_sasl_handler_get_channel (EmpathyServerSASLHandler *handler)
-{
-  EmpathyServerSASLHandlerPriv *priv;
-
-  g_return_val_if_fail (EMPATHY_IS_SERVER_SASL_HANDLER (handler), NULL);
-
-  priv = handler->priv;
-
-  return priv->channel;
-}
-
 gboolean
 empathy_server_sasl_handler_has_password (EmpathyServerSASLHandler *handler)
 {
@@ -516,40 +461,3 @@ empathy_server_sasl_handler_has_password (EmpathyServerSASLHandler *handler)
 
   return (priv->password != NULL);
 }
-
-/**
- * empathy_server_sasl_handler_can_save_response_somewhere:
- * @self:
- *
- * Returns: %TRUE if the response can be saved somewhere, either the keyring
- *   or via Ch.I.CredentialsStorage
- */
-gboolean
-empathy_server_sasl_handler_can_save_response_somewhere (
-    EmpathyServerSASLHandler *self)
-{
-  EmpathyServerSASLHandlerPriv *priv;
-  gboolean may_save_response, may_save_response_valid;
-  gboolean has_storage_iface;
-
-  g_return_val_if_fail (EMPATHY_IS_SERVER_SASL_HANDLER (self), FALSE);
-
-  priv = self->priv;
-
-  /* determine if we are permitted to save the password locally */
-  may_save_response = tp_asv_get_boolean (
-      tp_channel_borrow_immutable_properties (priv->channel),
-      TP_PROP_CHANNEL_INTERFACE_SASL_AUTHENTICATION_MAY_SAVE_RESPONSE,
-      &may_save_response_valid);
-
-  if (!may_save_response_valid)
-    {
-      DEBUG ("MaySaveResponse unknown, assuming TRUE");
-      may_save_response = TRUE;
-    }
-
-  has_storage_iface = tp_proxy_has_interface_by_id (priv->channel,
-      EMP_IFACE_QUARK_CHANNEL_INTERFACE_CREDENTIALS_STORAGE);
-
-  return may_save_response || has_storage_iface;
-}
